@@ -22,15 +22,12 @@
 #include "actionlist.h"
 #include "appsmodel.h"
 #include "containmentinterface.h"
-#include "menuentryeditor.h"
 
 #include <config-X11.h>
-#include <config-appstream.h>
 
 #include <QProcess>
 #include <QQmlPropertyMap>
 #include <QStandardPaths>
-#include <QDesktopServices>
 #if HAVE_X11
 #include <QX11Info>
 #endif
@@ -48,12 +45,6 @@
 
 #include <Plasma/Plasma>
 
-#ifdef HAVE_APPSTREAMQT
-#include <AppStreamQt/pool.h>
-#endif
-
-MenuEntryEditor *AppEntry::m_menuEntryEditor = nullptr;
-
 AppEntry::AppEntry(AbstractModel *owner, KService::Ptr service, NameFormat nameFormat)
 : AbstractEntry(owner)
 , m_service(service)
@@ -88,10 +79,6 @@ void AppEntry::init(NameFormat nameFormat)
     } else {
         m_description = nameFromService(m_service, GenericNameOnly);
     }
-
-    if (!m_menuEntryEditor) {
-        m_menuEntryEditor = new MenuEntryEditor();
-    }
 }
 
 bool AppEntry::isValid() const
@@ -131,6 +118,11 @@ QString AppEntry::id() const
     return m_service->storageId();
 }
 
+QString AppEntry::menuId() const
+{
+    return m_service->menuId();
+}
+
 QUrl AppEntry::url() const
 {
     return QUrl::fromLocalFile(m_service->entryPath());
@@ -141,28 +133,6 @@ bool AppEntry::hasActions() const
     return true;
 }
 
-#ifdef HAVE_APPSTREAMQT
-Q_GLOBAL_STATIC(AppStream::Pool, appstreamPool)
-
-QVariantList appstreamActions(const KService::Ptr &service)
-{
-    if (!appstreamPool.exists()) {
-        appstreamPool->load();
-    }
-
-    QVariantList ret;
-    const auto components = appstreamPool->componentsById(service->desktopEntryName()+QLatin1String(".desktop"));
-    for(const auto &component: components) {
-        const QString componentId = component.id();
-
-        QVariantMap appstreamAction = Kicker::createActionItem(i18nc("@action opens a software center with the application", "Manage '%1'...", component.name()), "manageApplication", QVariant(QStringLiteral("appstream://") + componentId));
-        appstreamAction[QStringLiteral("icon")] = QStringLiteral("applications-other");
-        ret << appstreamAction;
-    }
-    return ret;
-}
-#endif
-
 QVariantList AppEntry::actions() const
 {
     QVariantList actionList;
@@ -193,19 +163,11 @@ QVariantList AppEntry::actions() const
         return actionList;
     }
 
-    if (m_menuEntryEditor->canEdit(m_service->entryPath())) {
-        actionList << Kicker::createSeparatorActionItem();
-
-        QVariantMap editAction = Kicker::createActionItem(i18n("Edit Application..."), "editApplication");
-        editAction["icon"] = "kmenuedit"; // TODO: Using the KMenuEdit icon might be misleading.
-        actionList << editAction;
-    }
-
-#ifdef HAVE_APPSTREAMQT
     if (m_service->isApplication()) {
-        actionList << appstreamActions(m_service);
+        actionList << Kicker::createSeparatorActionItem();
+        actionList << Kicker::editApplicationAction(m_service);
+        actionList << Kicker::appstreamActions(m_service);
     }
-#endif
 
     QQmlPropertyMap *appletConfig = qobject_cast<QQmlPropertyMap *>(appletInterface->property("configuration").value<QObject *>());
 
@@ -248,12 +210,10 @@ bool AppEntry::run(const QString& actionId, const QVariant &argument)
 
     if (Kicker::handleAddLauncherAction(actionId, appletInterface, m_service)) {
         return true;
-    } else if (actionId == "editApplication" && m_menuEntryEditor->canEdit(m_service->entryPath())) {
-        m_menuEntryEditor->edit(m_service->entryPath(), m_service->menuId());
-
+    } else if (Kicker::handleEditApplicationAction(actionId, m_service)) {
+        return true;
+    } else if (Kicker::handleAppstreamActions(actionId, argument)) {
         return true;
-    } else if (actionId == "manageApplication") {
-        return QDesktopServices::openUrl(QUrl(argument.toString()));
     } else if (actionId == "_kicker_jumpListAction") {
         return KRun::run(argument.toString(), {}, nullptr, m_service->name(), m_service->icon());
     }
