@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 201 by Eike Hein <hein@kde.org>                         *
+ *   Copyright (C) 2015 by Eike Hein <hein@kde.org>                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -32,6 +32,11 @@ FileEntry::FileEntry(AbstractModel *owner, const QUrl &url) : AbstractEntry(owne
     }
 }
 
+FileEntry::~FileEntry()
+{
+    delete m_fileItem;
+}
+
 bool FileEntry::isValid() const
 {
     return m_fileItem && (m_fileItem->isFile() || m_fileItem->isDir());
