@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 201 by Eike Hein <hein@kde.org>                         *
+ *   Copyright (C) 2015 by Eike Hein <hein@kde.org>                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -28,22 +28,23 @@ class FileEntry : public AbstractEntry
 {
     public:
         explicit FileEntry(AbstractModel *owner, const QUrl &url);
+        ~FileEntry();
 
-        EntryType type() const { return RunnableType; }
+        EntryType type() const Q_DECL_OVERRIDE { return RunnableType; }
 
-        bool isValid() const;
+        bool isValid() const Q_DECL_OVERRIDE;
 
-        QIcon icon() const;
-        QString name() const;
-        QString description() const;
+        QIcon icon() const Q_DECL_OVERRIDE;
+        QString name() const Q_DECL_OVERRIDE;
+        QString description() const Q_DECL_OVERRIDE;
 
-        QString id() const;
-        QUrl url() const;
+        QString id() const Q_DECL_OVERRIDE;
+        QUrl url() const Q_DECL_OVERRIDE;
 
-        bool hasActions() const;
-        QVariantList actions() const;
+        bool hasActions() const Q_DECL_OVERRIDE;
+        QVariantList actions() const Q_DECL_OVERRIDE;
 
-        bool run(const QString& actionId = QString(), const QVariant &argument = QVariant());
+        bool run(const QString& actionId = QString(), const QVariant &argument = QVariant()) Q_DECL_OVERRIDE;
 
     private:
         KFileItem *m_fileItem;
