@@ -30,7 +30,7 @@ class GroupSortProxy : public QSortFilterProxyModel
     Q_OBJECT
 
     public:
-        explicit GroupSortProxy(QAbstractItemModel *sourceModel);
+        explicit GroupSortProxy(AbstractModel *parentModel, QAbstractItemModel *sourceModel);
         ~GroupSortProxy();
 
     protected:
