@@ -27,7 +27,10 @@
 #include <QPixmap>
 #include <QPointer>
 
+#include "backend.h"
+
 DragHelper::DragHelper(QObject* parent) : QObject(parent)
+, m_dragIconSize(32)
 {
 }
 
@@ -35,6 +38,20 @@ DragHelper::~DragHelper()
 {
 }
 
+int DragHelper::dragIconSize() const
+{
+    return m_dragIconSize;
+}
+
+void DragHelper::setDragIconSize(int size)
+{
+    if (m_dragIconSize != size) {
+        m_dragIconSize = size;
+
+        emit dragIconSizeChanged();
+    }
+}
+
 bool DragHelper::isDrag(int oldX, int oldY, int newX, int newY) const
 {
     return ((QPoint(oldX, oldY) - QPoint(newX, newY)).manhattanLength() >= QApplication::startDragDistance());
@@ -57,7 +74,7 @@ void DragHelper::startDragInternal(QQuickItem *item, const QString &mimeType,
     QPointer<QQuickItem> grabber = item;
 
     QList<QUrl> urlList;
-    urlList.append(url);
+    urlList.append(Backend::tryDecodeApplicationsUrl(url));
 
     QMimeData *dragData = new QMimeData();
     dragData->setData(mimeType, mimeData.toByteArray());
@@ -66,8 +83,7 @@ void DragHelper::startDragInternal(QQuickItem *item, const QString &mimeType,
 
     QDrag *drag = new QDrag(static_cast<QQuickItem *>(parent()));
     drag->setMimeData(dragData);
-    drag->setPixmap(icon.pixmap(QSize(48, 48)));
-    drag->setHotSpot(QPoint(drag->pixmap().width() / 2, drag->pixmap().height() / 2));
+    drag->setPixmap(icon.pixmap(QSize(m_dragIconSize, m_dragIconSize)));
 
     grabber->grabMouse();
 
