@@ -63,7 +63,7 @@ public:
     void setUrl(const QString& url);
     QString url() const;
 
-    QVariant data(const QModelIndex &index, int role) const;
+    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
     int count() const {return rowCount();}
 
     Q_INVOKABLE int indexForUrl(const QString &url) const;
