@@ -55,6 +55,7 @@ class KNewFileMenu;
 
 namespace KIO {
     class DropJob;
+    class StatJob;
 }
 
 class ScreenMapper;
@@ -313,6 +314,7 @@ class FOLDERPLUGIN_TESTS_EXPORT FolderModel : public QSortFilterProxyModel, publ
         KDirWatch *m_dirWatch;
         QString m_url;
         QHash<QUrl, bool> m_isDirCache;
+        mutable QHash<QUrl, KIO::StatJob *> m_isDirJobs;
         QItemSelectionModel *m_selectionModel;
         QItemSelection m_pinnedSelection;
         QModelIndexList m_dragIndexes;
