@@ -23,14 +23,13 @@
 
 #include <PlasmaQuick/Dialog>
 
-class QScreen;
 
 class SubDialog : public PlasmaQuick::Dialog
 {
     Q_OBJECT
 
     public:
-        SubDialog(QQuickItem *parent = 0);
+        explicit SubDialog(QQuickItem *parent = nullptr);
         ~SubDialog();
 
         Q_INVOKABLE QRect availableScreenRectForItem(QQuickItem *item) const;
