@@ -30,7 +30,7 @@ class WheelInterceptor : public QQuickItem
     Q_PROPERTY(QObject* destination READ destination WRITE setDestination NOTIFY destinationChanged)
 
     public:
-        WheelInterceptor(QQuickItem *parent = 0);
+        explicit WheelInterceptor(QQuickItem *parent = nullptr);
         ~WheelInterceptor();
 
         QObject *destination() const;
@@ -40,7 +40,7 @@ class WheelInterceptor : public QQuickItem
         void destinationChanged() const;
 
     protected:
-        void wheelEvent(QWheelEvent *event) Q_DECL_OVERRIDE;
+        void wheelEvent(QWheelEvent *event) override;
 
     private:
         QPointer<QObject> m_destination;
