@@ -35,9 +35,9 @@ public:
     KAccessConfig(QWidget *parent, const QVariantList&);
     virtual ~KAccessConfig();
 
-    void load();
-    void save();
-    void defaults();
+    void load() Q_DECL_OVERRIDE;
+    void save() Q_DECL_OVERRIDE;
+    void defaults() Q_DECL_OVERRIDE;
 
 protected Q_SLOTS:
 
@@ -48,6 +48,7 @@ protected Q_SLOTS:
     void selectSound();
     void changeFlashScreenColor();
     void configureKNotify();
+    void launchOrcaConfiguration();
 
 private:
     Ui::access ui;
