@@ -21,6 +21,7 @@
 #include "scmeditoroptions.h"
 #include "scmeditorcolors.h"
 #include "scmeditoreffects.h"
+#include "colorscm.h"
 
 #include <QDebug>
 #include <QDir>
@@ -34,17 +35,38 @@
 
 #include <KNS3/UploadDialog>
 
-SchemeEditorDialog::SchemeEditorDialog(const QString &path, QWidget *parent)
+SchemeEditorDialog::SchemeEditorDialog(KSharedConfigPtr config, KColorCm *parent)
+    : QDialog( parent )
+    , m_disableUpdates(false)
+    , m_unsavedChanges(false)
+    , m_kcm(parent)
+{
+    m_config = config;
+    init();
+}
+
+SchemeEditorDialog::SchemeEditorDialog(const QString &path, KColorCm *parent)
     : QDialog( parent )
     , m_filePath(path)
     , m_disableUpdates(false)
     , m_unsavedChanges(false)
+    , m_kcm(parent)
 {
     m_config = KSharedConfig::openConfig(path);
-    m_schemeName = KConfigGroup(m_config, "General").readEntry("Name");
 
-    setupUi(this);
+    m_schemeName = KConfigGroup(m_config, "General").readEntry("Name");
     this->setWindowTitle(m_schemeName);
+    init();
+}
+
+void SchemeEditorDialog::init()
+{
+    setupUi(this);
+
+    //we are in standalone appication mode? don't show the apply button
+    if (!m_kcm) {
+        buttonBox->button(QDialogButtonBox::Apply)->setVisible(false);
+    }
 
     schemeKnsUploadButton->setIcon( QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")) );
 
@@ -52,9 +74,10 @@ SchemeEditorDialog::SchemeEditorDialog(const QString &path, QWidget *parent)
     m_colorTab = new SchemeEditorColors(m_config);
     m_disabledTab = new SchemeEditorEffects(m_config, QPalette::Disabled);
     m_inactiveTab = new SchemeEditorEffects(m_config, QPalette::Inactive);
-    tabWidget->insertTab(OptionTab, m_optionTab, i18n("Options"));
-    tabWidget->insertTab(ColorTab, m_colorTab, i18n("Colors"));
-    tabWidget->insertTab(DisabledTab, m_disabledTab, i18n("Disabled"));
+    tabWidget->addTab(m_optionTab, i18n("Options"));
+    tabWidget->addTab(m_colorTab, i18n("Colors"));
+    tabWidget->addTab(m_disabledTab, i18n("Disabled"));
+    tabWidget->setCurrentWidget(m_colorTab);
 
     connect(m_optionTab, &SchemeEditorOptions::changed, this, &SchemeEditorDialog::updateTabs);
     connect(m_colorTab, &SchemeEditorColors::changed, this, &SchemeEditorDialog::updateTabs);
@@ -106,6 +129,11 @@ void SchemeEditorDialog::on_buttonBox_clicked(QAbstractButton *button)
     {
         saveScheme();
     }
+    else if (buttonBox->standardButton(button) == QDialogButtonBox::Apply)
+    {
+        applyScheme();
+        emit applied();
+    }
     else if (buttonBox->standardButton(button) == QDialogButtonBox::Close)
     {
         if (m_unsavedChanges) {
@@ -123,6 +151,16 @@ void SchemeEditorDialog::on_buttonBox_clicked(QAbstractButton *button)
     }
 }
 
+void SchemeEditorDialog::applyScheme()
+{
+    if (!m_kcm) {
+        return;
+    }
+
+    m_kcm->updateConfig(m_config);
+    m_kcm->save();
+}
+
 void SchemeEditorDialog::saveScheme()
 {
     // prompt for the name to save as
@@ -205,11 +243,11 @@ void SchemeEditorDialog::updateTabs(bool madeByUser)
     bool hideInactiveTab = group.readEntry("Enable", QVariant(true)).toBool();
     if ( hideInactiveTab )
     {
-        tabWidget->insertTab(InactiveTab, m_inactiveTab, i18n("Inactive"));
+        tabWidget->addTab(m_inactiveTab, i18n("Inactive"));
     }
     else
     {
-        tabWidget->removeTab(InactiveTab);
+        tabWidget->removeTab(tabWidget->indexOf(m_inactiveTab));
     }
 
     m_optionTab->updateValues();
