@@ -124,7 +124,7 @@ DesktopPathConfig::DesktopPathConfig(QWidget *parent, const QVariantList &)
   urAutostart = addRow(lay, i18n("Autostart path:"),
                        i18n("This folder contains applications or"
                             " links to applications (shortcuts) that you want to have started"
-                            " automatically whenever KDE starts. You can change the location of this"
+                            " automatically whenever the session starts. You can change the location of this"
                             " folder if you want to, and the contents will move automatically"
                             " to the new location as well."));
 
