@@ -46,22 +46,22 @@ IconModule::IconModule(QWidget *parent, const QVariantList &)
   layout->addWidget(tab);
 
   tab1 = new IconThemesConfig(this);
-  tab1->setObjectName( QLatin1String( "themes" ) );
+  tab1->setObjectName( QStringLiteral( "themes" ) );
   tab->addTab(tab1, i18n("&Theme"));
   connect(tab1, SIGNAL(changed(bool)), this, SLOT(moduleChanged(bool)));
 
   tab2 = new KIconConfig(this);
-  tab2->setObjectName( QLatin1String( "effects" ) );
+  tab2->setObjectName( QStringLiteral( "effects" ) );
   tab->addTab(tab2, i18n("Ad&vanced"));
   connect(tab2, SIGNAL(changed(bool)), this, SLOT(moduleChanged(bool)));
 
-  KAboutData* about = new KAboutData("kcmicons", i18n("Icons"), QStringLiteral("1.0"),
+  KAboutData* about = new KAboutData(QStringLiteral("kcmicons"), i18n("Icons"), QStringLiteral("1.0"),
                                      i18n("Icons Control Panel Module"), KAboutLicense::GPL,
                                      i18n("(c) 2000-2003 Geert Jansen"));
-  about->addAuthor(i18n("Geert Jansen"), QString(), "jansen@kde.org");
-  about->addAuthor(i18n("Antonio Larrosa Jimenez"), QString(), "larrosa@kde.org");
-  about->addCredit(i18n("Torsten Rahn"), QString(), "torsten@kde.org");
-  about->addAuthor(i18n("Jonathan Riddell"), QString(), "jr@jriddell.org");
+  about->addAuthor(i18n("Geert Jansen"), QString(), QStringLiteral("jansen@kde.org"));
+  about->addAuthor(i18n("Antonio Larrosa Jimenez"), QString(), QStringLiteral("larrosa@kde.org"));
+  about->addCredit(i18n("Torsten Rahn"), QString(), QStringLiteral("torsten@kde.org"));
+  about->addAuthor(i18n("Jonathan Riddell"), QString(), QStringLiteral("jr@jriddell.org"));
   setAboutData( about );
 }
 
