@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
- 
+
 
 #ifndef KEYBOARDPAINTER_H
 #define KEYBOARDPAINTER_H
@@ -25,20 +25,27 @@
 #include <QDialog>
 
 class QPushButton;
+class QComboBox;
 
 class KeyboardPainter : public QDialog
 {
     Q_OBJECT
-    
+
 public:
     explicit KeyboardPainter();
     ~KeyboardPainter();
+    void generateKeyboardLayout(const QString &layout, const QString &variant, const QString &model, const QString &title);
+    int getHeight();
+    int getWidth();
+
+public Q_SLOTS:
+    void levelChanged(int l_id);
 
-    void generateKeyboardLayout(const QString& layout, const QString& variant);
-    
 private:
+    QDialog *kbDialog;
     KbPreviewFrame *kbframe;
     QPushButton *exitButton;
+    QComboBox *levelBox;
 };
 
 #endif // KEYBOARDPAINTER_H
