@@ -19,16 +19,17 @@
 #ifndef KEYSYMHELPER_H
 #define KEYSYMHELPER_H
 
-#include <QtCore/QString>
-#include <QtCore/QMap>
+#include <QString>
+#include <QMap>
 
 class KeySymHelper
 {
 public:
     KeySymHelper();
-    
+
     QString getKeySymbol(const QString &opton);
-    bool isFailed() const {
+    bool isFailed() const
+    {
         return nill >= 120;
     }
 
