@@ -26,13 +26,15 @@
 
 #include <QThread>
 #include <QTreeWidget>
-#include <KDialog>
+#include <QDialog>
 #include "Misc.h"
 #include "JobRunner.h"
 
 class QLabel;
 class QMenu;
 class QAction;
+class QDialogButtonBox;
+class QAbstractButton;
 
 namespace KFI
 {
@@ -84,7 +86,7 @@ class CFontFileList : public QThread
 
     private:
 
-    void run();
+    void run() Q_DECL_OVERRIDE;
     void fileDuplicates(const QString &folder, const QSet<TFile> &files);
 
     private:
@@ -137,7 +139,7 @@ class CFontFileListView : public QTreeWidget
     void unmark();
     void selectionChanged();
     void clicked(QTreeWidgetItem *item, int col);
-    void contextMenuEvent(QContextMenuEvent *ev);
+    void contextMenuEvent(QContextMenuEvent *ev) Q_DECL_OVERRIDE;
 
     private:
 
@@ -150,7 +152,7 @@ class CFontFileListView : public QTreeWidget
             *itsUnMarkAct;
 };
 
-class CDuplicatesDialog : public KDialog
+class CDuplicatesDialog : public QDialog
 {
     Q_OBJECT
 
@@ -158,16 +160,18 @@ class CDuplicatesDialog : public KDialog
 
     CDuplicatesDialog(QWidget *parent, CFontList *fl);
 
-    int               exec();
+    int               exec() Q_DECL_OVERRIDE;
     const CFontList * fontList() const    { return itsFontList; }
 
     private Q_SLOTS:
 
     void scanFinished();
-    void slotButtonClicked(int button);
+    void slotButtonClicked(QAbstractButton *button);
+    void enableButtonOk(bool);
 
     private:
 
+    QDialogButtonBox  *itsButtonBox;
     CActionLabel      *itsActionLabel;
     CFontFileList     *itsFontFileList;
     QLabel            *itsLabel;
