@@ -22,23 +22,22 @@
 #ifndef KFONTINST_EXPORT_H
 #define KFONTINST_EXPORT_H
 
-/* needed for KDE_EXPORT macros */
-#include <kdemacros.h>
+#include <QtGlobal>
 
 #if defined _WIN32 || defined _WIN64
 
 #ifndef KFONTINST_EXPORT
 # if defined(MAKE_KFONTINST_LIB)
-#  define KFONTINST_EXPORT KDE_EXPORT
+#  define KFONTINST_EXPORT Q_DECL_EXPORT
 # else
-#  define KFONTINST_EXPORT KDE_IMPORT
+#  define KFONTINST_EXPORT Q_DECL_IMPORT
 # endif
 #endif
 
 
 #else /* UNIX */
 
-#define KFONTINST_EXPORT KDE_EXPORT
+#define KFONTINST_EXPORT Q_DECL_EXPORT
 
 #endif
 
