@@ -33,9 +33,9 @@ class SMServerConfig : public KCModule
 public:
   explicit SMServerConfig( QWidget *parent=0, const QVariantList &list=QVariantList() );
 
-  void load();
-  void save();
-  void defaults();
+  void load() Q_DECL_OVERRIDE;
+  void save() Q_DECL_OVERRIDE;
+  void defaults() Q_DECL_OVERRIDE;
 
 private:
   SMServerConfigImpl* dialog;
