@@ -24,8 +24,6 @@
 #include "config-workspace.h"
 #include <klauncher_iface.h>
 
-#include <KPluginFactory>
-#include <KPluginLoader>
 #include <KAboutData>
 #include <KSharedConfig>
 #include <QDebug>
@@ -57,8 +55,6 @@
 #  include <X11/extensions/Xfixes.h>
 #endif
 
-K_PLUGIN_FACTORY_WITH_JSON(KCMLookandFeelFactory, "kcm_lookandfeel.json", registerPlugin<KCMLookandFeel>();)
-
 KCMLookandFeel::KCMLookandFeel(QObject* parent, const QVariantList& args)
     : KQuickAddons::ConfigModule(parent, args)
     , m_config(QStringLiteral("kdeglobals"))
@@ -445,7 +441,7 @@ void KCMLookandFeel::setColors(const QString &scheme, const QString &colorFile)
     KConfigGroup configGroup(&m_config, "General");
     configGroup.writeEntry("ColorScheme", scheme);
 
-    KSharedConfigPtr conf = KSharedConfig::openConfig(colorFile);
+    KSharedConfigPtr conf = KSharedConfig::openConfig(colorFile, KSharedConfig::CascadeConfig);
     foreach (const QString &grp, conf->groupList()) {
       KConfigGroup cg(conf, grp);
       KConfigGroup cg2(&m_config, grp);
@@ -813,6 +809,3 @@ bool KCMLookandFeel::resetDefaultLayout() const
 {
     return m_resetDefaultLayout;
 }
-
-
-#include "kcm.moc"
