@@ -45,9 +45,9 @@ public:
     SearchConfigModule(QWidget* parent, const QVariantList& args);
 
 public Q_SLOTS:
-    void load();
-    void save();
-    void defaults();
+    void load() Q_DECL_OVERRIDE;
+    void save() Q_DECL_OVERRIDE;
+    void defaults() Q_DECL_OVERRIDE;
 
 private:
     KPluginSelector *m_pluginSelector;
